pub mod api;
#[macro_use] extern crate rocket;
use dotenv::dotenv;
use rocket::{Build, Rocket};
use log::{error, info};
use std::{env, process};
use crate::api::util::read_p5x_config;

fn configure_rocket() -> Rocket<Build> {
    rocket::build()
        .attach(api::init())
}

#[tokio::main]
async fn main() {
    dotenv().ok();
    env_logger::init();
    info!(target: "p5x", "Starting p5x...");

    let args: Vec<String> = env::args().collect();
    if args.len() < 2 {
        error!(target: "p5x", "Missing required <mode> argument. Valid modes: api-server");
        process::exit(1);
    }

    read_p5x_config();  // Do this so we early-fail if there are missing env vars

    let mode = &args[1];
    if mode == "api-server" {
        let rocket = configure_rocket();
        if let Err(e) = rocket.launch().await {
            error!(target: "p5x", "Rocket failed to launch: {:?}", e)
        }
        return;
    }
}
